Attribute VB_Name = "GLinicializace"
Public Sub SetupPalette(ByVal lhDC As Long)
    
' +-------------------------------------------------------------------
' | Initialize the Win32 form pallete.
' +-------------------------------------------------------------------
    
    Dim PixelFormat As Long
    Dim pfd As PIXELFORMATDESCRIPTOR
    Dim pPal As LOGPALETTE
    Dim PaletteSize As Long
    PixelFormat = GetPixelFormat(lhDC)
    DescribePixelFormat lhDC, PixelFormat, Len(pfd), pfd
    If (pfd.dwFlags And PFD_NEED_PALETTE) <> 0 Then
        PaletteSize = 2 ^ pfd.cColorBits
    Else
        Exit Sub
    End If
    
    pPal.palVersion = &H300
    pPal.palNumEntries = PaletteSize
    Dim redMask As Long
    Dim GreenMask As Long
    Dim BlueMask As Long
    Dim i As Long
    redMask = 2 ^ pfd.cRedBits - 1
    GreenMask = 2 ^ pfd.cGreenBits - 1
    BlueMask = 2 ^ pfd.cBlueBits - 1
    For i = 0 To PaletteSize - 1
        With pPal.palPalEntry(i)
            .peRed = i
            .peGreen = i
            .peBlue = i
            .peFlags = 0
        End With
    Next
    GetSystemPaletteEntries hDC, 0, 256, VarPtr(pPal.palPalEntry(0))
    hPalette = CreatePalette(pPal)
    If hPalette <> 0 Then
        SelectPalette lhDC, hPalette, False
        RealizePalette lhDC
    End If
End Sub

Public Sub SetupPixelFormat(ByVal hDC As Long)

' +-------------------------------------------------------------------
' | Retrieve/set a Win32 pixel format for OpenGL modes with double-
' | buffering, and direct draw to window with RGBA color mode.
' | 16bit (65536 colors) depth is preferable.
' +-------------------------------------------------------------------

    Dim pfd As PIXELFORMATDESCRIPTOR
    Dim PixelFormat As Integer
    pfd.nSize = Len(pfd)
    pfd.nVersion = 1
    pfd.dwFlags = PFD_SUPPORT_OPENGL Or PFD_DRAW_TO_WINDOW Or PFD_DOUBLEBUFFER Or PFD_TYPE_RGBA
    pfd.iPixelType = PFD_TYPE_RGBA
    pfd.cColorBits = 16
    pfd.cDepthBits = 16
    pfd.iLayerType = PFD_MAIN_PLANE
    PixelFormat = ChoosePixelFormat(hDC, pfd)
    If PixelFormat = 0 Then FatalError "Could not retrieve pixel format!"
    SetPixelFormat hDC, PixelFormat, pfd
End Sub
Public Sub SetupPixelFormatStereo(ByVal hDC As Long)

' activate stereo buffering
' +-------------------------------------------------------------------
' | Retrieve/set a Win32 pixel format for OpenGL modes with double-
' | buffering, and direct draw to window with RGBA color mode.
' | 16bit (65536 colors) depth is preferable.
' +-------------------------------------------------------------------

    Dim pfd As PIXELFORMATDESCRIPTOR
    Dim PixelFormat As Integer
    pfd.nSize = Len(pfd)
    pfd.nVersion = 1
    pfd.dwFlags = PFD_SUPPORT_OPENGL Or PFD_DRAW_TO_WINDOW Or PFD_DOUBLEBUFFER Or PFD_TYPE_RGBA Or PFD_STEREO
    pfd.iPixelType = PFD_TYPE_RGBA
    pfd.cColorBits = 16
    pfd.cDepthBits = 16
    pfd.iLayerType = PFD_MAIN_PLANE
    PixelFormat = ChoosePixelFormat(hDC, pfd)
    If PixelFormat = 0 Then FatalError "Could not retrieve pixel format!"
    SetPixelFormat hDC, PixelFormat, pfd
End Sub
Public Sub SetupPixelFormatStencil(ByVal hDC As Long)

' activate stencil buffer
' +-------------------------------------------------------------------
' | Retrieve/set a Win32 pixel format for OpenGL modes with double-
' | buffering, and direct draw to window with RGBA color mode.
' | 16bit (65536 colors) depth is preferable.
' +-------------------------------------------------------------------

    Dim pfd As PIXELFORMATDESCRIPTOR
    Dim PixelFormat As Integer
    pfd.nSize = Len(pfd)
    pfd.nVersion = 1
    pfd.dwFlags = PFD_SUPPORT_OPENGL Or PFD_DRAW_TO_WINDOW Or PFD_DOUBLEBUFFER Or PFD_TYPE_RGBA
    pfd.iPixelType = PFD_TYPE_RGBA
    pfd.cColorBits = 16
    pfd.cDepthBits = 16
    pfd.iLayerType = PFD_MAIN_PLANE
    pfd.cStencilBits = 1 ' maximum is sometimes only 1 but it is sufficient
    PixelFormat = ChoosePixelFormat(hDC, pfd)
    If PixelFormat = 0 Then FatalError "Could not retrieve pixel format!"
    SetPixelFormat hDC, PixelFormat, pfd
End Sub
Public Sub FatalError(ByVal strMessage As String)

' +-------------------------------------------------------------------
' | A simple exit handler should something NASTY happen.
' +-------------------------------------------------------------------

    MsgBox "Fatal Error: " & strMessage, vbCritical + vbApplicationModal + vbOKOnly + vbDefaultButton1, "Fatal Error In " & App.Title
    Unload frmMain
    Set frmMain = Nothing
    End
End Sub

Public Sub ZapniGLfunkce()

    glEnable GL_DEPTH_TEST ' enable depth buffering
     glEnable GL_DITHER ' enable dithering, no effect ??
    glDepthFunc GL_LESS ' pedantic defolt value
    glClearDepth 1 'pedantic defolt value
    ' frame buffer clears should be to black
    glEnable GL_COLOR_MATERIAL 'enable color surfaces
    
End Sub

Public Sub Osvetli()
' lighting activation

Dim MatSpecular(3) As GLfloat
Dim MatShininess(0) As GLfloat
Dim LightPosition(3) As GLfloat
' transfer parameters via 32 bit fields
    MatSpecular(0) = 1
    MatSpecular(1) = 1
    MatSpecular(2) = 1
    MatSpecular(3) = 1
    MatShininess(0) = 50
' light position -> Head Light in 0,0,100
    LightPosition(0) = 0
    LightPosition(1) = 0
    LightPosition(2) = 100
    LightPosition(3) = 0
' declaration of interaction with light properties
    glMaterialfv GL_FRONT, GL_SPECULAR, MatSpecular(0)
    glMaterialfv GL_FRONT, GL_SHININESS, MatShininess(0)
'setting the light
    glLightfv GL_LIGHT0, GL_POSITION, LightPosition(0)
'enabling the light
    glEnable GL_LIGHTING
    glEnable GL_LIGHT0
    
End Sub
